@@ -63,7 +63,7 @@ class SetupWizard(Gtk.Assistant):
      CHANNEL_SCAN_PAGE,
      SAVE_CHANNELS_PAGE,
      SETUP_DEVICE_PAGE,
-     SUMMARY_PAGE) = range(7)
+     SUMMARY_PAGE) = list(range(7))
 
     def __init__(self):
         GObject.GObject.__init__(self)
@@ -152,7 +152,7 @@ class SetupWizard(Gtk.Assistant):
             self.__ask_on_exit = True
             if self.__adapter_info["name"] != None:
                 page.start_scanning(self.__adapter_info["adapter"],
-                    self.__adapter_info["frontend"], self.tuning_data_page.get_tuning_data ())
+                    self.__adapter_info["frontend"], self.__adapter_info["type"], self.tuning_data_page.get_tuning_data ())
         elif isinstance(page, SetupDevicePage):
             page.set_adapter(self.__adapter_info)
             page.set_scanner(self.scan_page.get_scanner())
